
Causal ML
=========

Perpetual provides specialized modules for causal inference, treatment effect estimation, and interpretable decision-making.

.. toctree::
   :maxdepth: 1
   :caption: Solution Guides

   uplift
   dml
   policy
   iv
   risk
   fairness
